@@ -1,20 +1,6 @@
 """
-Odnoklassniki.ru OAuth2 and IFRAME application support
-If you are using OAuth2 authentication,
-    * Take a look to:
-        http://dev.odnoklassniki.ru/wiki/display/ok/The+OAuth+2.0+Protocol
-    * You need to register OAuth application here:
-        http://dev.odnoklassniki.ru/wiki/pages/viewpage.action?pageId=13992188
-elif you're building iframe application,
-    * Take a look to:
-        http://dev.odnoklassniki.ru/wiki/display/ok/
-                Odnoklassniki.ru+Third+Party+Platform
-    * You need to register your iframe application here:
-        http://dev.odnoklassniki.ru/wiki/pages/viewpage.action?pageId=5668937
-    * You need to sign a public offer and do some bureaucracy if you want to be
-      listed in application registry
-Then setup your application according manual and use information from
-registration mail to set settings values.
+Odnoklassniki OAuth2 and Iframe Application backends, docs at:
+    http://psa.matiasaguirre.net/docs/backends/odnoklassnikiru.html
 """
 from hashlib import md5
 
@@ -102,8 +88,8 @@ class OdnoklassnikiApp(BaseAuth):
         return self.strategy.authenticate(*args, **kwargs)
 
     def get_auth_sig(self):
-        secret_key = self.setting('APP_SECRET')
-        hash_source = '{0:d}{1:s}{2:s}'.format(self.data['logged_user_id'],
+        secret_key = self.setting('SECRET')
+        hash_source = '{0:s}{1:s}{2:s}'.format(self.data['logged_user_id'],
                                                self.data['session_key'],
                                                secret_key)
         return md5(hash_source).hexdigest()
