@@ -1,14 +1,6 @@
 """
-Tumblr OAuth 1.0a support.
-
-Take a look to http://www.tumblr.com/docs/en/api/v2
-
-You need to register OAuth site here: http://www.tumblr.com/oauth/apps
-
-Then update your settings values using registration information
-
-ref:
-    https://github.com/gkmngrgn/django-tumblr-auth
+Tumblr OAuth1 backend, docs at:
+    http://psa.matiasaguirre.net/docs/backends/tumblr.html
 """
 from social.utils import first
 from social.backends.oauth import BaseOAuth1
@@ -16,7 +8,7 @@ from social.backends.oauth import BaseOAuth1
 
 class TumblrOAuth(BaseOAuth1):
     name = 'tumblr'
-    ID_KEY = 'username'
+    ID_KEY = 'name'
     AUTHORIZATION_URL = 'http://www.tumblr.com/oauth/authorize'
     REQUEST_TOKEN_URL = 'http://www.tumblr.com/oauth/request_token'
     REQUEST_TOKEN_METHOD = 'POST'
